/*********************************************************************
 *
 *                Microchip USB C18 Firmware Version 1.2
 *
 *********************************************************************
 * FileName:        io_cfg.h
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18
 * Compiler:        C18 3.11+
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the Company) for its PICmicro Microcontroller is intended and
 * supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Rawin Rojvanit       11/19/04    Original.
 * 
 * Steve Russell		    
 ******************************************************************************
 * Change log
 * ----------
 * 04Mar08 - Modified to match mistralXG pin allocation
 * 04Jul08 - Added in I2C pin definitions
 *
 *****************************************************************************/
#ifndef IO_CFG_H
#define IO_CFG_H

/** I N C L U D E S *************************************************/
#include "autofiles\usbcfg.h"

/** T R I S *********************************************************/
#define INPUT_PIN           1
#define OUTPUT_PIN          0

/** U S B ***********************************************************/
#define tris_usb_bus_sense  TRISCbits.TRISC2    // Input

#if defined(USE_USB_BUS_SENSE_IO)
#define usb_bus_sense       PORTCbits.RC2
#else
#define usb_bus_sense       1
#endif

// We're always Self-powered
//#define tris_self_power     TRISAbits.TRISA2    // Input

#if defined(USE_SELF_POWER_SENSE_IO)
#define self_power          PORTAbits.RA2
#else
#define self_power          1
#endif

/** TIMING INFO ******/
#define CLOCKSPEED	48000000	        // 48MHz clock
#define CPUCLK		(CLOCKSPEED/4) 		// Instruction clock freq
#define CYCLETIME	(1000000000/CPUCLK)	// Cycle time in ns

/** S W I T C H *****************************************************/
// Macro to set switch pins as inputs, MIDI controls as outputs 
// and pullups for the inputs. RC1 is set as an output to provide PWM for the
// backlight - it also needs to be an output when used for timing measurement
// so we set it here. Uncomment the definition of CHK_TIMING to use RC1 for
// that purpose, otherwise it controls the backlight
//#define CHK_TIMING
#define mInitIO()       TRISB = 0b11000011; DDRCbits.RC1=0; INTCON2bits.RBPU=0;
#define swsel           PORTBbits.RB7
#define swset           PORTBbits.RB6

/** CONTROL OUTPUTS *************************************************/
// These control the hardware switching of MIDI streams
#define bIntMIDISel     PORTBbits.RB5
#define bEnMIDIOut      PORTBbits.RB4
#define bEnMIDIThru     PORTBbits.RB3
#define bWX5Sel         PORTBbits.RB2

/** 16x2 LCD Panel ***********************************************
 * The panel uses PortA(RA5:RA0) and PortC(RC0) - see mxg_xlcd.h
 */

/** I2C defs to go here ***************************************
 * SCL is PortBbits.RB1, SDA is PortBbits.RB0
 * These have to be configured as inputs for use as I2C
 */
#define I2C_SCL	TRISBbits.TRISB1
#define I2C_SDA	TRISBbits.TRISB0

#endif //IO_CFG_H
