/******************************************************************************
 *
 *  Filename:       interrupt.h
 *  Project:        mistralXG Wind synthesiser
 *  Date:           12Apr08
 *  File Version:   01.00
 *
 *
 *  Author:     Steve Russell (pic.projects@ntlworld.com)
 *  Company:    Grapevyne
 *
 *  Copyright:  (C) Steve Russell 2008
 *
 *  This code is available at no charge to individuals for personal, non-profit,
 *  use, and may be used as is or modifed as desired. Further distribution of
 *  this code or a derivative work is allowed as long as this copyright notice
 *  is not removed or modified. Changes to the original code should be clearly
 *  identified.
 *
 *  Any commercial use of this code, or a derivative of it, may only be made
 *  with the written agreement of the copyright holder. "Commercial" in this
 *  context means any activity that requires a user to pay in money or kind
 *  in order to make use of such code.
 *
 *  This file is provided "as is". No claims of suitability for any particular
 *  purpose are made. No liability for any damages (of any sort) resulting from
 *  its use are accepted, no matter how they may arise.
 *
 ******************************************************************************
 * Change log
 * ----------
 *
 *
 *****************************************************************************/

#ifndef INTERRUPT_H
#define INTERRUPT_H

/** I N C L U D E S **********************************************************/
#include "system\typedefs.h"

/** D E F I N I T I O N S ****************************************************/
// Macros to control Global Interrupts
#define mEnableInterrupts()         INTCONbits.GIE = 1;
#define mDisableInterrupts()        INTCONbits.GIE = 0;
// Timer interrupt macros
#define mEnableTimerInt()			INTCONbits.TMR0IE=1;
#define mDisableTimerInt()			INTCONbits.TMR0IE=0;
#define mClearTimerInt()			INTCONbits.TMR0IF=0;
// Switch interrupt macros
//#define mEnableSwitchInt()			INTCONbits.RBIE=1;
//#define mDisableSwitchInt()			INTCONbits.RBIE=0;
// EUSART interrupt macros
#define mEnableRxInt()		    	PIE1bits.RCIE=1;
#define mDisableRxInt() 			PIE1bits.RCIE=0;
#define mEnableTxInt()		    	PIE1bits.TXIE=1;
#define mDisableTxInt()	    		PIE1bits.TXIE=0;

/* TIMING INFO (see also IOCFG.H) */
	
#define INTERVAL (256-(1000000/(64*CYCLETIME))+1)	// 1ms (approx) interrupt
#define DISP_REFRESH 100        // Display refresh interval (100ms)
#define DISP_TIMEOUT 5000       // Display timeout period (5s)
#define RS_TIMEOUT 250          // Running status timeout (250ms)
/** S T R U C T U R E S ******************************************************/

/** E X T E R N S ************************************************************/

extern volatile byte displayTmr;    // Refresh timer for the LCD
extern volatile WORD dispTimeout;   // Timeout timer for display
extern volatile byte rsInjectTmr;   // Timeout counter for resending status byte
extern volatile byte debounceTmr;   // Debounce timer for the buttons
extern volatile byte swStatus, savedSwStatus;   // Button state variables
extern volatile BOOL bChange;
/** P R O T O T Y P E S ******************************************************/
void low_isr(void);
void high_isr(void);

#endif //INTERRUPT_H




