/******************************************************************************
 *
 *  Filename:       user.h
 *  Project:        mistralXG Wind synthesiser
 *  Date:           12Apr08
 *  File Version:   01.00
 *
 *
 *  Author:     Steve Russell (pic.projects@ntlworld.com)
 *  Company:    Grapevyne
 *
 *  Copyright:  (C) Steve Russell 2008
 *
 *  This code is available at no charge to individuals for personal, non-profit,
 *  use, and may be used as is or modifed as desired. Further distribution of
 *  this code or a derivative work is allowed as long as this copyright notice
 *  is not removed or modified. Changes to the original code should be clearly
 *  identified.
 *
 *  Any commercial use of this code, or a derivative of it, may only be made
 *  with the written agreement of the copyright holder. "Commercial" in this
 *  context means any activity that requires a user to pay in money or kind
 *  in order to make use of such code.
 *
 *  This file is provided "as is". No claims of suitability for any particular
 *  purpose are made. No liability for any damages (of any sort) resulting from
 *  its use are accepted, no matter how they may arise.
 *
 ******************************************************************************
 * Change log
 * ----------
 * 01Jul08 - First implementation of EEPROM storage for user options
 *
 *
 *****************************************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"
#include "user\mxg_eeprom.h"

/** V A R I A B L E S ********************************************************/
BOOL   writingEEPROM;    // Flag to indicate we're writing to the EEPROM


/******************************************************************************
 * Function:        void initEEPROM(void)
 * PreCondition:    None
 * Input:           None
 * Output:          None
 * Side Effects:    EEPROM is ready for access
 * Overview:        
 * Note:            None
 *****************************************************************************/
void initEEPROM(void)
{
    EECON1bits.CFGS = 0;    // Make sure we're not accessing Config registers
    EECON1bits.EEPGD = 0;   // ... and the EEPROM, not flash.
    writingEEPROM = FALSE;  // We're not writing to start with
}


/******************************************************************************
 * Function:        unsigned char readEEPROM(unsigned char address)
 * PreCondition:    None
 * Input:           The address in EEPROM to be read
 * Output:          EEPROM data from the supplied address
 * Side Effects:    None
 * Overview:        
 * Note:            None
 *****************************************************************************/
byte readEEPROM(byte address)
{
    // We never access flash, so first steps are done in initEEPROM
    // EECON1bits.CFGS = 0;    // Not config bits
    // EECON1bits.EEPGD = 0;   // EEPROM access, not flash
    EEADR = address;        // Set address 
    EECON1bits.RD = 1;      // Trigger the read
    return EEDATA;          // ...and return the data
}

/******************************************************************************
 * Function:        void writeEEPROM(unsigned char data, unsigned char address)
 * PreCondition:    None
 * Input:           The address in EEPROM to be read
 * Output:          EEPROM data from the supplied address
 * Side Effects:    None
 * Overview:        
 * Note:            None
 *****************************************************************************/
void writeEEPROM(byte data, byte address)
{
    // We never access flash, so first steps are done in initEEPROM
    // EECON1bits.CFGS = 0;   // Not config bits
    // EECON1bits.EEPGD = 0;  // EEPROM access, not flash
    EECON1bits.WREN = 1;    // Enable writes
    EEADR = address;        // Set address
    EEDATA = data;          // Set data
    INTCONbits.GIE = 0;     // Disable interrupts over the critical section
    EECON2 = 0x55;          // Arm the write sequence
    EECON2 = 0xAA;          // ... continue it
    EECON1bits.WR = 1;      // Start the write
    INTCONbits.GIE = 1;     // Re-enable interrupts
    writingEEPROM = TRUE;    // Set the flag to say we're writing to the EEPROM
}