/******************************************************************************
 *
 *  Filename:       mxg_error.c
 *  Project:        mistralXG Wind synthesiser
 *  Date:           12Apr08
 *  File Version:   01.00
 *
 *
 *  Author:     Steve Russell (pic.projects@ntlworld.com)
 *  Company:    Grapevyne
 *
 *  Copyright:  (C) Steve Russell 2008
 *
 *  This code is available at no charge to individuals for personal, non-profit,
 *  use, and may be used as is or modifed as desired. Further distribution of
 *  this code or a derivative work is allowed as long as this copyright notice
 *  is not removed or modified. Changes to the original code should be clearly
 *  identified.
 *
 *  Any commercial use of this code, or a derivative of it, may only be made
 *  with the written agreement of the copyright holder. "Commercial" in this
 *  context means any activity that requires a user to pay in money or kind
 *  in order to make use of such code.
 *
 *  This file is provided "as is". No claims of suitability for any particular
 *  purpose are made. No liability for any damages (of any sort) resulting from
 *  its use are accepted, no matter how they may arise.
 *
 ******************************************************************************
 * Change log
 * ----------
 *
 *
 *****************************************************************************/
 
/******************************************************************************
 * mistralXG error flags and counters
 *****************************************************************************/
 
/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"
#include "system\interrupt\interrupt.h"
#include "user\mxg_error.h"
#include "user\mxg_msgs.h"
#include "user\mxg_iface.h"

/** Error Flags **************************************************************/
// These flags are used to indicate when their respective errors have occurred
// See mxg_error.h for the individual flag assignments.
flags sFlags;

/** Error Counters ***********************************************************/
// EUSART error counters - see interrupt.c 
// These are volatile as they are used by the ISR. The counters are two bytes
// so interrupts should be disabled when they are accessed to eliminate invalid
// values being read.
counters errctrs;

/******************************************************************************
 * Clear all the error flags and counts before starting everything off.
 * This is called when interrupts are enabled sometimes, so we have to make
 * sure there are no interrupts while clearing the EUSART error counters and
 * flags, and also the global error flag. Originally used a loop, which was
 *  unrolled for performance (5.1us instead of 42.8us).
 *****************************************************************************/
void clearErrors(void)
{
    byte i;

    mDisableRxInt();
    sFlags.rcvBufFull=NOERR;
    sFlags.rcvFERR=NOERR;
    sFlags.rcvOERR=NOERR;
    errctrs.rcvBFCnt=0;
    errctrs.rcvFECnt=0;
    errctrs.rcvOECnt=0;
    ERRFLAG = NOERRS;                   // Clear flag on Home display
    mEnableRxInt();

    sFlags.DATNotExpctd=NOERR;
    sFlags.VM1NotExpctd=NOERR;
    sFlags.VM2NotExpctd=NOERR;
    sFlags.SC0NotExpctd=NOERR;
    sFlags.SC1NotExpctd=NOERR;
    sFlags.SC2NotExpctd=NOERR;
    sFlags.SYXNotExpctd=NOERR;
    sFlags.EOXNotExpctd=NOERR;
    sFlags.SC0F4Rcvd=NOERR;
    sFlags.SC0F5Rcvd=NOERR;
    sFlags.SRTF9Rcvd=NOERR;
    sFlags.SRTFDRcvd=NOERR;
    sFlags.MSBOFlow=NOERR;
    errctrs.DATNECnt=0;
    errctrs.VM1NECnt=0;
    errctrs.VM2NECnt=0;
    errctrs.SC0NECnt=0;
    errctrs.SC1NECnt=0;
    errctrs.SC2NECnt=0;
    errctrs.SYXNECnt=0;
    errctrs.EOXNECnt=0;
    errctrs.SC0F4Cnt=0;
    errctrs.SC0F5Cnt=0;
    errctrs.SRTF9Cnt=0;
    errctrs.SRTFDCnt=0;
    errctrs.MSBOFCnt=0;
}


