/******************************************************************************
 *
 *  Filename:       mxg_error.h
 *  Project:        mistralXG Wind synthesiser
 *  Date:           12Apr08
 *  File Version:   01.00
 *
 *
 *  Author:     Steve Russell (pic.projects@ntlworld.com)
 *  Company:    Grapevyne
 *
 *  Copyright:  (C) Steve Russell 2008
 *
 *  This code is available at no charge to individuals for personal, non-profit,
 *  use, and may be used as is or modifed as desired. Further distribution of
 *  this code or a derivative work is allowed as long as this copyright notice
 *  is not removed or modified. Changes to the original code should be clearly
 *  identified.
 *
 *  Any commercial use of this code, or a derivative of it, may only be made
 *  with the written agreement of the copyright holder. "Commercial" in this
 *  context means any activity that requires a user to pay in money or kind
 *  in order to make use of such code.
 *
 *  This file is provided "as is". No claims of suitability for any particular
 *  purpose are made. No liability for any damages (of any sort) resulting from
 *  its use are accepted, no matter how they may arise.
 *
 ******************************************************************************
 * Change log
 * ----------
 *
 *
 *****************************************************************************/
 
/******************************************************************************
 * mistralXG error flags and counters
 *****************************************************************************/

#ifndef __MXG_ERROR_H
#define __MXG_ERROR_H

/** Error Flags **************************************************************/
// These flags are used to indicate when their respective errors have occurred
// They are defined as char because they are used to display error status on
// the LCD. The EUSART error flags are volatile as they are used in the ISR.
union _FLAGS {
    char fa[16];                    // So we can access the flags as an array
    struct {
        volatile char rcvBufFull;   // We've rcvd more MIDI data than can handle
        volatile char rcvFERR;      // Framing error on receive
        volatile char rcvOERR;      // Overflow error on receive
        char DATNotExpctd;          // Data byte received when not expected
        char VM1NotExpctd;          // VM1 status received when not expected
        char VM2NotExpctd;          // VM2 status received when not expected
        char SC0NotExpctd;          // SC0 status received when not expected
        char SC1NotExpctd;          // SC1 status received when not expected
        char SC2NotExpctd;          // SC2 status received when not expected
        char SYXNotExpctd;          // Sysex status received when not expected
        char EOXNotExpctd;          // End of Sysex received when not expected
        char SC0F4Rcvd;             // SC0 F4 received
        char SC0F5Rcvd;             // SC0 F5 received
        char SRTF9Rcvd;             // SRT F9 received
        char SRTFDRcvd;             // SRT FD received
        char MSBOFlow;              // MIDI staging buffer overflow
    };
};
typedef union _FLAGS flags;

extern flags sFlags;

#define NOERR '_'
#define ERR_0 'B'	// Receive buffer full
#define ERR_1 'F'	// Receive framing error
#define ERR_2 'O'	// Receive overflow error
#define ERR_3 'D'	// Unexpected data
#define ERR_4 '1'	// Unexpected VM1
#define ERR_5 '2'	// Unexpected VM2
#define ERR_6 '0'	// Unexpected SC0
#define ERR_7 '1'	// Unexpected SC1
#define ERR_8 '2'	// Unexpected SC2
#define ERR_9 'S'	// Unexpected SYSEX
#define ERR_A 'E'	// Unexpected EOX
#define ERR_B '4'	// Unexpected F4
#define ERR_C '5'	// Unexpected F5
#define ERR_D '9'	// Unexpected F9
#define ERR_E 'D'	// Unexpected FD
#define ERR_F 'M'	// MIDI staging buffer overflow



/** Error Counters ***********************************************************/
// EUSART error counters - see interrupt.c 
// These are volatile as they are used by the ISR. The counters are two bytes
// so interrupts should be disabled when they are accessed to eliminate invalid
// values being read.
union _COUNTERS {
    word ca[16];                    // So we can access the flags as an array
    struct {
        // EUSART error counters - mxg_usart.c
        volatile word rcvBFCnt;     // Rcv'd more MIDI data than we can handle
        volatile word rcvFECnt;     // Framing error on receive
        volatile word rcvOECnt;     // Overflow error on receive
        // MIDI error counters - see msg_musm.c
        word DATNECnt;              // Data byte received when not expected
        word VM1NECnt;              // VM1 status received when not expected
        word VM2NECnt;              // VM2 status received when not expected
        word SC0NECnt;              // SC0 status received when not expected
        word SC1NECnt;              // SC1 status received when not expected
        word SC2NECnt;              // SC2 status received when not expected
        word SYXNECnt;              // Sysex status received when not expected
        word EOXNECnt;              // End of Sysex received when not expected
        word SC0F4Cnt;              // SC0 F4 received
        word SC0F5Cnt;              // SC0 F5 received
        word SRTF9Cnt;              // SRT F9 received
        word SRTFDCnt;              // SRT FD received
        word MSBOFCnt;              // MIDI staging buffer overflow
    };
};
typedef union _COUNTERS counters;

extern counters errctrs;

/** P U B L I C  P R O T O T Y P E S *****************************************/
void clearErrors(void);

#endif // _MXG_ERROR_H