/*****************************************************************************
 *
 *  Filename:       mxg_iface.h
 *  Project:        mistralXG Wind synthesiser
 *  Date:           12Apr08
 *  File Version:   01.00
 *
 *
 *  Author:     Steve Russell (pic.projects@ntlworld.com)
 *  Company:    Grapevyne
 *
 *  Copyright:  (C) Steve Russell 2008
 *
 *  This code is available at no charge to individuals for personal, non-profit,
 *  use, and may be used as is or modifed as desired. Further distribution of
 *  this code or a derivative work is allowed as long as this copyright notice
 *  is not removed or modified. Changes to the original code should be clearly
 *  identified.
 *
 *  Any commercial use of this code, or a derivative of it, may only be made
 *  with the written agreement of the copyright holder. "Commercial" in this
 *  context means any activity that requires a user to pay in money or kind
 *  in order to make use of such code.
 *
 *  This file is provided "as is". No claims of suitability for any particular
 *  purpose are made. No liability for any damages (of any sort) resulting from
 *  its use are accepted, no matter how they may arise.
 *
 ******************************************************************************
 * Change log
 * ----------
 * 16Jul08 - changed display flags to support USB connected and single flag for
 *           WX5, MIDI and USB
 * 15Oct08 - Switched dBACKLIGHT and dERRORS order so backlight can be reached
 *           easily if an error has occurred.
 *
 *****************************************************************************/
 
/******************************************************************************
 * mistralXG Higher level display handler header file
 *****************************************************************************/
#ifndef __MXG_DISPLAY_H
#define __MXG_DISPLAY_H

// Masks for the switches (see io_cfg.h)
#define SELMASK         0x80
#define SETMASK         0x40
#define SWMASK          (SELMASK | SETMASK)
#define bSelect         (~SELMASK & SWMASK)
#define bSet            (~SETMASK & SWMASK)
#define bBoth           (bSelect & bSet)
#define bNone           SWMASK
#define DEBOUNCE        25             // Debounce time in ms

// Activity timer to slow down updates for MIDI activity
#define ACT_TIMER 2

// Defines for switch flags used in the display
#define NOERRS      ' '
#define ERROR       '!'

#define WX5IN       'W'     // WX5 input
#define MIDIIN      'M'     // External MIDI input
#define USBIN       'U'     // USB MIDI input

#define USBENABLED  0x0b
#define USBDISABLED ' '

#define EnThruTRUE  'T'
#define EnThruFALSE '_'

#define EnOutTRUE   'O'
#define EnOutFALSE  '_'

#define EnRSTRUE    'R'
#define EnRSFALSE   '_'

#define EnFiltTRUE  'F'
#define EnFiltFALSE '_'


// Button indicators for selection screens
#define SELECT      '\x009'
#define UNSELECT    '\x00A'
// Indicator for brightness bar
#define INDICATOR   '\x009' 

/******************************************************************************
 * Enum for the display states. 
 *
 * IMPORTANT:
 * Be *very* careful when changing this enum. The order is important.
 *
 * The error values dERR0-eERRF *must* be the first entries as they are used to
 * index into the array of char array pointers for the error text and the error
 * counter array.
 *****************************************************************************/
enum screen {
    dERR0, dERR1, dERR2, dERR3, dERR4, dERR5, dERR6, dERR7,
    dERR8, dERR9, dERRA, dERRB, dERRC, dERRD, dERRE, dERRF,
    dRESETALL,
    dSPLASH, dHOME, dWX5EXT, dUSBEXT, dMIDITHRU, dMIDIOUT, 
    dRUNSTAT, dFILTER, dERRORS, dBACKLIGHT};
typedef enum screen screen;


typedef union _sPTR
{
    char* sRam;                 // Ram byte pointer: 2 bytes pointer pointing
                                // to 1 byte of data
    rom char* sRom;             // Size depends on compiler setting
    BYTE* sRam1;
} sPTR;

/*********************************
 * Functions written to support non-blocking update of the LCD
 *********************************/
void setDisplay(screen);
void nextChar(void);
void doSelect(void);
void doSet(void);
void refreshDisplay(void);
void initInterface(void);

extern byte WritesToLCDPending;
extern byte brightness;
extern BOOL brightChange;

#endif // _MXG_DISPLAY_H