/******************************************************************************
 *
 *  Filename:       mxg_msgs.c
 *  Project:        mistralXG Wind synthesiser
 *  Date:           12Apr08
 *  File Version:   01.00
 *
 *
 *  Author:     Steve Russell (pic.projects@ntlworld.com)
 *  Company:    Grapevyne
 *
 *  Copyright:  (C) Steve Russell 2008
 *
 *  This code is available at no charge to individuals for personal, non-profit,
 *  use, and may be used as is or modifed as desired. Further distribution of
 *  this code or a derivative work is allowed as long as this copyright notice
 *  is not removed or modified. Changes to the original code should be clearly
 *  identified.
 *
 *  Any commercial use of this code, or a derivative of it, may only be made
 *  with the written agreement of the copyright holder. "Commercial" in this
 *  context means any activity that requires a user to pay in money or kind
 *  in order to make use of such code.
 *
 *  This file is provided "as is". No claims of suitability for any particular
 *  purpose are made. No liability for any damages (of any sort) resulting from
 *  its use are accepted, no matter how they may arise.
 *
 ******************************************************************************
 * Change log
 * ----------
 * 04Aug08 - Change HOME display to show MIDI activity, and reorganise error
 *           display logic.
 * 24Sep08 - Changed implementation of brightness bar display
 *
 *****************************************************************************/
 
/******************************************************************************
 * mistralXG messages used on the LCD
 *****************************************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"
#include "user\mxg_msgs.h"

/** LCD Message Strings ******************************************************/
// Each line of the display is 16 chars long. We don't want the null terminator
// so define the arrays' lengths and ignore resulting compiler warnings
rom char sSplash[16]     =   "mistralXG  v1.03";
// \x008 is the (c) char, defined in charpatt[] (see mxg_lcd.c)
rom char sCpyrght[16]    =   "\x0082008, Grapevyne"; 

// Home screen.... last 6 chars are user option flags
char sHome[16]          =   "mistralXG";
BYTE sActivity[16];     // Array to display MIDI activity (BYTE for bit access)

// \x009, \x00A are the select/deselect char, defined in charpatt[] (mxg_lcd.c)
// Can't use symbolic names here as they're chars in strings (see mxg_iface.h)
rom char sExtMidi[16]   =   "Ext MIDI Source:";
rom char sExtInput[16]  =   "\x009WX5    \x00AMIDI   ";

rom char sExtInt[16]    =   "MIDI to Synth:  ";
rom char sSynthSel[16]  =   "\x009Ext    \x00AUSB    ";

rom char sExtThru[16]   =   "Ext MIDI Thru:  ";
rom char sEnable[16]    =   "\x009Enable \x00ADisable";

rom char sMidiOut[16]   =   "USB MIDI Out:   ";
// sEnable

rom char sRunStat[16]   =   "Running status: ";
// sEnable

rom char sFilter[16]    =   "Filter bad MIDI:";
// sEnable

/* Not implemented
rom char sReset[16]     =   "Reset?          ";
rom char sNoYes[16]     =   "\x009No     \x00AYes    ";
*/

rom char sErrors[16]    =   "Error flags:    ";
// sFlags makes the second line (see mxg_error.c)

rom char sBacklight[16] =   "Backlight:      ";

/** Error count messages **/
rom char eRcvBufFul[16] =   "Rcv Buffer full:";
rom char eRcvFramErr[16]=   "Rcv Framing err:";
rom char eRcvOflwErr[16]=   "Rcv Ovrflow err:";
rom char eDATNE[16]     =   "Data byte error:";
rom char eVM1NE[16]     =   "Voice Msg 1 err:";
rom char eVM2NE[16]     =   "Voice Msg 2 err:";
rom char eSC0NE[16]     =   "Sys Ctrl 0 err: ";
rom char eSC1NE[16]     =   "Sys Ctrl 1 err: ";
rom char eSC2NE[16]     =   "Sys Ctrl 2 err: ";
rom char eSYXNE[16]     =   "Sysex errors:   ";
rom char eEOXNE[16]     =   "EOX errors:     ";
rom char eF4Err[16]     =   "Sys Ctrl F4 err:";
rom char eF5Err[16]     =   "Sys Ctrl F5 err:";
rom char eF9Err[16]     =   "Sys Ctrl F9 err:";
rom char eFDErr[16]     =   "Sys Ctrl FD err:";
rom char eMSOvrFlow[16] =   "MIDI buffer err:";
rom char eResetErr[16]  =   "\x00AReset      xxxx";
rom char eResetCtrs[16] =   "Error counters: ";
rom char eResetAll[16]  =   "\x00AReset all      ";

// Array of pointers to the error messages... matches the order of the error
// counters in mxg_error.h
rom char * rom errdisp[] = {eRcvBufFul,
                            eRcvFramErr,
                            eRcvOflwErr,
                            eDATNE,
                            eVM1NE,
                            eVM2NE,
                            eSC0NE,
                            eSC1NE,
                            eSC2NE,
                            eSYXNE,
                            eEOXNE,
                            eF4Err,
                            eF5Err,
                            eF9Err,
                            eFDErr,
                            eMSOvrFlow};