/******************************************************************************
 *
 *  Filename:       mxg_usart.h
 *  Project:        mistralXG Wind synthesiser
 *  Date:           12Apr08
 *  File Version:   01.00
 *
 *
 *  Author:     Steve Russell (pic.projects@ntlworld.com)
 *  Company:    Grapevyne
 *
 *  Copyright:  (C) Steve Russell 2008
 *
 *  This code is available at no charge to individuals for personal, non-profit,
 *  use, and may be used as is or modifed as desired. Further distribution of
 *  this code or a derivative work is allowed as long as this copyright notice
 *  is not removed or modified. Changes to the original code should be clearly
 *  identified.
 *
 *  Any commercial use of this code, or a derivative of it, may only be made
 *  with the written agreement of the copyright holder. "Commercial" in this
 *  context means any activity that requires a user to pay in money or kind
 *  in order to make use of such code.
 *
 *  This file is provided "as is". No claims of suitability for any particular
 *  purpose are made. No liability for any damages (of any sort) resulting from
 *  its use are accepted, no matter how they may arise.
 *
 ******************************************************************************
 * Change log
 * ----------
 *
 *
 *****************************************************************************/
 
/******************************************************************************
 * mistralXG EUSART routines header file
 *****************************************************************************/
#ifndef __MXG_USART_H
#define __MXG_USART_H

//These are settings purely for Async mode
// TXSTA register
#define USART_ASYNC			0b11100111	// Set Async mode, no break char
#define USART_8_BIT			0b10111111  // 8-bit data (also for RCSTA)
#define USART_TX_ENABLE		0b11111111	// Enable Tx
#define USART_TX_DISABLE	0b11011111	// Disable Tx
#define USART_HI_SPEED		0b11111111	// Set hi speed mode
#define USART_LO_SPEED		0b11111011	// Set lo speed mode
// RCSTA register
#define USART_SPEN			0b11111111	// Enable the serial port
#define USART_SPDIS			0b01111111	// Disable the serial port
// 8-bit as for TXSTA
#define USART_RX_ENABLE		0b11111111	// Enable Rx
#define USART_RX_DISABLE	0b11101111	// Disable Rx

// Error bit masks for RCSTA
#define USART_FERR			0b00000100	// Framing error
#define USART_OERR			0b00000010	// Overrun error

/** P U B L I C  P R O T O T Y P E S *****************************************/
void initUSART(void);

/** USART BUFFER DEFINITIONS *************************************************/
// Non-portable - but makes pointer arithmetic easier/faster for USART
typedef union 
{
    byte *bufptr;
    struct
    {
        byte lo;
        byte hi;
    } bytes;
} bp;
// Some buffer defines and macros (see mxg_usart.c)
#define TXB_SIZE 128        // At 0x700
#define RXB_SIZE 8          // At 0x780
#define txbMask	(TXB_SIZE-1)
#define rxbMask ((RXB_SIZE-1)|0x80)

// mRxBufNotFull() is used inside the interrupt handler.
// Check it's safe if used outside the ISR.
#define mRxBufNotFull() (((rxbend.bytes.lo+1)&rxbMask)!=rxbstart.bytes.lo)
// mRxDataRdy() is interrupt safe as the interrupt only ever increases rxbend
// (wrapping at the end of the buffer), but will not bump it to be equal to
// rxbstart.
#define mRxDataRdy()    (rxbstart.bytes.lo!=rxbend.bytes.lo)
// mTxBufEmpty() is used inside the interrupt handler.
// Check it's safe if used outside the ISR.
#define mTxBufEmpty()   (txbstart.bytes.lo==txbend.bytes.lo)

/** EXTERNS *****************/
extern volatile bp txbstart, txbend;
extern volatile bp rxbstart, rxbend;

#endif // _MXG_USART_H